/*
 * SCMD.c
 *
 *  Created on: 20 may. 2018
 *      Author: Javier Artacho
 */
#include "configHardware.h"
#include <SPI.h>
#include <Wire.h>
#include <Stdio.h>
#include "SCMD.h"

//function that manages the driver depending on the value received 1 for forward, 2 for rearwards, 3 to turn right, 4 to turn left and 0 to stop
void SCMD::moveMotors(int dirct) {
    uint8_t direction;
    uint8_t level;
    int16_t driveValue; //use to build value to actually write to register
    uint8_t level_right;
    uint8_t level_left;

    switch (dirct) {
    case 1:
        /* move both motors forwards*/
         Wire.beginTransmission(addressI2C); // transmit to device 89 (0x59)
         Wire.write(0x20+0);                //right motor
         direction=0;                       //direction of turn (0 forward)
         level_right=160;                   //speed for the right wheel
         level_left=150;                    //speed for the left wheel
         //convert to 7 bit
         level_right = level_right >> 1;

         driveValue = (level_right * direction) + ((int8_t)level_right * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_right * direction);
                 driveValue += 128;
         Wire.write(driveValue);
         Wire.endTransmission();


         level_left = level_left >> 1;          //convert to 7 bit

         driveValue = (level_left * direction) + ((int8_t)level_left * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_left * direction);
                          driveValue += 128;
         Wire.beginTransmission(addressI2C); // transmit to device 89 (0x59)
         Wire.write(0x20+1); //left motor
         Wire.write(driveValue);
         Wire.endTransmission();
         break;
    case 2:
        /* move both motors rearwards*/
         Wire.beginTransmission(addressI2C); // transmit to device 89 (0x59)
         Wire.write(0x20+0);                //right motor
         direction=1;                       //direction of turn (1 rearwards)
         level=150;                         //speed for the wheel

         level = level >> 1;                //convert to 7 bit


         driveValue = (level * direction) + ((int8_t)level * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level * direction);
                 driveValue += 128;
         Wire.write(driveValue);
         Wire.endTransmission();
         Wire.beginTransmission(addressI2C); // transmit to device 89 (0x59)
         Wire.write(0x20+1);                //left motor
         Wire.write(driveValue);
         Wire.endTransmission();
         break;
    case 3:
        /* move left motor forwards*/
         Wire.beginTransmission(addressI2C); // transmit to device 89 (0x59)
         Wire.write(0x20+0);                //right motor
         direction=0;                       //direction of turn (0 forward)
         level_right=150;                   //speed for the right wheel
         level_left=0;                      //speed for the left wheel

         level_right = level_right >> 1;       //convert to 7 bit


         driveValue = (level_right * direction) + ((int8_t)level_right * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_right * direction);
                 driveValue += 128;
         Wire.write(driveValue);
         Wire.endTransmission();


         level_left = level_left >> 1;          //convert to 7 bit


         driveValue = (level_left * direction) + ((int8_t)level_left * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_left * direction);
                          driveValue += 128;
         Wire.beginTransmission(addressI2C);    // transmit to device 89 (0x59)
         Wire.write(0x20+1);                    //left motor
         Wire.write(driveValue);
         Wire.endTransmission();
         break;

    case 4:
        /* move right motor forwards*/
         Wire.beginTransmission(addressI2C);    // transmit to device 89 (0x59)
         Wire.write(0x20+0);                    //right motor
         direction=0;                           //direction of turn (0 forward)
         level_right=0;                         //speed for the right wheel
         level_left=140;                        //speed for the left wheel

         level_right = level_right >> 1;        //convert to 7 bit

         driveValue = (level_right * direction) + ((int8_t)level_right * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_right * direction);
                 driveValue += 128;
         Wire.write(driveValue);
         Wire.endTransmission();


         level_left = level_left >> 1;          //convert to 7 bit

         driveValue = (level_left * direction) + ((int8_t)level_left * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level_left * direction);
                          driveValue += 128;
         Wire.beginTransmission(addressI2C);    // transmit to device 89 (0x59)
         Wire.write(0x20+1);                    //left motor
         Wire.write(driveValue);
         Wire.endTransmission();
         break;

    case 0:
        /* stop both motors */
         Wire.beginTransmission(addressI2C);    // transmit to device 89 (0x59)
         Wire.write(0x20+0);                    //right motor
         direction=0;                           // direction not necessary, but kept as forward
         level=0;                               //speed for the wheels to zero because we want to stop

         level = level >> 1;                    //convert to 7 bit


         driveValue = (level * direction) + ((int8_t)level * ((int8_t)direction - 1)); //set to 1/2 drive if direction = 1 or -1/2 drive if direction = 0; (level * direction);
                 driveValue += 128;
         Wire.write(driveValue);
         Wire.endTransmission();
         Wire.beginTransmission(addressI2C);    // transmit to device 89 (0x59)
         Wire.write(0x20+1);                    //left motor
         Wire.write(driveValue);
         Wire.endTransmission();
         break;
    default:
        break;
    }
}

//Reset function
void SCMD::reset( void )
{
#ifdef USE_ALT_I2C
    //Blast the Teensy 3.1 i2c control register
    uint8_t * I2C_CTRL1_reg;
    I2C_CTRL1_reg = (uint8_t *)0x40066002;
    *I2C_CTRL1_reg = 0x00;
    //Waiting seems like a good idea
    delay(10);
    Wire.resetBus(); //Strictly resets.  Run .begin() afterwards
    Wire.begin();
#endif

}
